==> bitsensor-node-js-core-1.0.2.tgz: package/test/bitsensor_handler_test.js <==
require('../core/init');
var expect = require('chai').expect;
var ApplicationHandler = require('../core/handler/application_handler');
var VersionHandler = require('../core/handler/bitsensor_version_handler');
var EnvironmentHandler = require('../core/handler/environment_handler');
var TimeHandler = require('../core/handler/time_handler');
var Datapoint = require('./../core/datapoint');


describe('Post handle', function () {
  describe('Integration', function () {
    it('should not be empty', function () {
      var datapoint = new Datapoint();
      bitSensor.postHandlers[1].handle(datapoint);

      expect(datapoint.endpoint).to.not.empty;
    });
    it('should not be empty', function () {
      var datapoint = new Datapoint();
      bitSensor.postHandlers[0].handle(datapoint);
      expect(datapoint.meta).to.not.empty;
    });
  });
  describe('Unit', function () {
    describe('Version handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new VersionHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
    describe('Time handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new TimeHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
    describe('Environment handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new EnvironmentHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
    describe('Application handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new ApplicationHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
  });
});

==> bitsensor-node-js-core-1.1.0.tgz: package/test/bitsensor_handler_test.js <==
require('../core/init');
var expect = require('chai').expect;
var ApplicationHandler = require('../core/handler/application_handler');
var VersionHandler = require('../core/handler/bitsensor_version_handler');
var EnvironmentHandler = require('../core/handler/environment_handler');
var TimeHandler = require('../core/handler/time_handler');
var Datapoint = require('./../index').Datapoint;


describe('Post handle', function () {
  describe('Integration', function () {
    it('should not be empty', function () {
      var datapoint = new Datapoint();
      bitSensor.postHandlers[1].handle(datapoint);

      expect(datapoint.endpoint).to.not.empty;
    });
    it('should not be empty', function () {
      var datapoint = new Datapoint();
      bitSensor.postHandlers[0].handle(datapoint);
      expect(datapoint.meta).to.not.empty;
    });
  });
  describe('Unit', function () {
    describe('Version handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new VersionHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
    describe('Time handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new TimeHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
    describe('Environment handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new EnvironmentHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
    describe('Application handler', function () {
      it('should not be empty', function () {
        bitSensor.postHandlers = [];
        bitSensor.addPostHandler(new ApplicationHandler());
        expect(bitSensor.postHandlers.length).to.be.above(0);
      });
    });
  });
});
